@@ -88,7 +88,7 @@ def bootstrap_task(target, arguments, worker_id=None, channel=None):
     return result
 
 
-def GroupWorkers(target: FunctionType, arguments: list, concurrent: int, kernel=None):
+def GroupWorkers(target: FunctionType, arguments: list, concurrent: int, kernel=''):
     """
     Used to start a number concurrent threads of a target function and predefined arguments list
     :param target: function or method pointer
@@ -237,4 +237,4 @@ def __worker(wid, target, channel, lock, callback=None):
         with lock:
             channel.jobs -= 1
 
-    log(INFO, f'Worker<{wid}> exited')
\ No newline at end of file
+    log(INFO, f'Worker<{wid}> exited')
